@@ -1,9 +1,12 @@
 g.inspectfile = function(datafile) {
+  # note that if the file is an RData file then this function will not be called
+  # the output of this function for the original datafile is stored inside the RData file in the form of object I
   getbrand = function(filename=c(),datafile=c()) {
     sf = c(); isitageneactive = c();  isitagenea = c();  mon = c();dformat = c() #generating empty variables
     tmp1 = unlist(strsplit(filename,"[.]c"))
     tmp2 = unlist(strsplit(filename,"[.]b"))
     tmp3 = unlist(strsplit(filename,"[.]w"))
+    tmp4 = unlist(strsplit(filename,"[.]r"))
     if (tmp1[length(tmp1)] == "sv") { #this is a csv file
       dformat = 2 #2 = csv
       testcsv = read.csv(paste(datafile,sep=""),nrow=10,skip=10)
@@ -112,8 +115,8 @@ g.inspectfile = function(datafile) {
         }
       }
     } else if (dformat == 3) { # wav
-      # H = readWave(datafile,from = 1, to = 10,units = c("seconds"), header = TRUE)
-      # sf = H$sample.rate
+      H = tuneR::readWave(datafile,from = 1, to = 10,units = c("seconds"), header = TRUE)
+      sf = H$sample.rate
     }
     invisible(list(dformat=dformat,mon=mon,sf=sf))
   }
@@ -143,19 +146,19 @@ g.inspectfile = function(datafile) {
     } else if (mon == 3) { #geneactive
       H = read.csv(datafile,nrow=9,skip=0)
     }
-
+    
   } else if (dformat == 3) { #wav data
     header = rownames(read.csv(datafile,skipNul=TRUE,nrow=13,header=TRUE))
-  H = sapply(as.character(header),function(x) {
-    tmp = unlist(strsplit(x,": "))
-    if (length(tmp) == 1) {
-      tmp = c(tmp, NA)
-    }
-    tmp
-  })
-  H = as.data.frame(t(H))
-  names(H) = c("hnames","hvalues")
-      # H = read.csv(datafile,nrow=20,skip=0) #note that not the entire header is copied
+    H = sapply(as.character(header),function(x) {
+      tmp = unlist(strsplit(x,": "))
+      if (length(tmp) == 1) {
+        tmp = c(tmp, NA)
+      }
+      tmp
+    })
+    H = as.data.frame(t(H))
+    names(H) = c("hnames","hvalues")
+    # H = read.csv(datafile,nrow=20,skip=0) #note that not the entire header is copied
   }
   H = as.matrix(H)
   if (ncol(H) == 1 & dformat == 2) {
