@@ -1,5 +1,5 @@
 g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1,f1=0,
-                        do.report=c(2),overwrite=FALSE,visualreport=FALSE,...) {
+                        do.report=c(2),overwrite=FALSE,visualreport=FALSE,viewingwindow=1,...) {
   #get input variables
   input = list(...)
   if (length(input) > 0) {
@@ -17,6 +17,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(datadir) == 1) { #could be a directory or one file
     if (length(unlist(strsplit(datadir,"[.]bi")))>1) filelist = TRUE
     if (length(unlist(strsplit(datadir,"[.]cs")))>1) filelist = TRUE
+    if (length(unlist(strsplit(datadir,"[.]wa")))>1) filelist = TRUE
   } else { #multiple files
     filelist = TRUE
   }
@@ -31,22 +32,28 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     f0 = 1
     # What file to end with?
     if (filelist == FALSE) {
-      f1 = length(c(dir(datadir,recursive=TRUE,pattern="csv"),dir(datadir,recursive=TRUE,pattern="bin"))) #10
+      if (f1 != f0) {
+        fl <- length(dir(datadir, recursive = TRUE, pattern = "[.](csv|bin|Rda)")) # modified by JH
+        # f1 = length(c(dir(datadir,recursive=TRUE,pattern="csv"),dir(datadir,recursive=TRUE,pattern="bin"))) #10
+      }
     } else {
       f1 = length(datadir) #modified
     }
   }
-  dopart1 = dopart2 = dopart3 = dopart4 = FALSE
+  dopart1 = dopart2 = dopart3 = dopart4 = FALSE # dopart5 = FALSE
   if (length(which(mode == 0)) > 0) {
     dopart1 = TRUE
     dopart2 = TRUE
     dopart3 = TRUE
     dopart4 = TRUE
+    # dopart5 = TRUE
   } else {
+    # if (length(which(mode == 0)) > 0) dopart0 = TRUE
     if (length(which(mode == 1)) > 0) dopart1 = TRUE
     if (length(which(mode == 2)) > 0) dopart2 = TRUE
     if (length(which(mode == 3)) > 0) dopart3 = TRUE; do.anglez = TRUE
     if (length(which(mode == 4)) > 0) dopart4 = TRUE
+    # if (length(which(mode == 5)) > 0) dopart5 = TRUE
   }
   if (filelist == TRUE) {
     metadatadir = paste(outputdir,"/output_",studyname,sep="")
@@ -55,6 +62,10 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     metadatadir = paste(outputdir,"/output_",outputfoldername,sep="")
   }
   # obtain default parameter values if not provided:
+  
+  if (length(which(ls() == "selectdaysfile")) == 0)  selectdaysfile = c()
+  if (length(which(ls() == "diaryfile")) == 0)  diaryfile = c()
+  
   if (length(which(ls() == "overwrite")) == 0)  overwrite = FALSE
   if (length(which(ls() == "strategy")) == 0)  strategy = 1
   if (length(which(ls() == "maxdur")) == 0)  maxdur = 7
@@ -64,6 +75,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "loglocation")) == 0)  loglocation = c()
   if (length(which(ls() == "storefolderstructure")) == 0)  storefolderstructure = FALSE
   if (length(which(ls() == "windowsizes")) == 0)  windowsizes = c(5,900,3600)
+  if (length(which(ls() == "minloadcrit")) == 0)  minloadcrit = 72
   if (length(which(ls() == "desiredtz")) == 0)  desiredtz = "Europe/London"
   if (length(which(ls() == "chunksize")) == 0)  chunksize = 1
   if (length(which(ls() == "do.enmo")) == 0)  do.enmo = TRUE
@@ -111,15 +123,36 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "visualreport")) == 0)  visualreport = FALSE
   if (length(which(ls() == "print.filename")) == 0)  print.filename = FALSE
   if (length(which(ls() == "backup.cal.coef")) == 0)  backup.cal.coef = c()
+  if (length(which(ls() == "mvpa.2014")) == 0)  mvpa.2014 = FALSE
+  if (length(which(ls() == "closedbout")) == 0)  closedbout = FALSE
   
+#   # # specific for part 5
+#   if (length(which(ls() == "boutcriter.in")) == 0)  boutcriter.in = 0.9
+#   if (length(which(ls() == "boutcriter.lig")) == 0)  boutcriter.lig = 0.8
+#   if (length(which(ls() == "boutcriter.mvpa")) == 0)  boutcriter.mvpa = 0.8
+#   if (length(which(ls() == "threshold.lig")) == 0)  threshold.lig = 40
+#   if (length(which(ls() == "threshold.mod")) == 0)  threshold.mod = 100
+#   if (length(which(ls() == "threshold.vig")) == 0)  threshold.vig = 400
+#   if (length(which(ls() == "timewindow")) == 0)  timewindow = c("MM","WW")
+#   if (length(which(ls() == "boutdur.mvpa")) == 0)  boutdur.mvpa = c(1,5,10)
+#   if (length(which(ls() == "boutdur.in")) == 0)  boutdur.in = c(10,20,30)
+#   if (length(which(ls() == "boutdur.lig")) == 0)  boutdur.lig = c(1,5,10)
+
+  # part 2
+  if (length(which(ls() == "mvpadur")) == 0)  mvpadur = c(1,5,10) # related to part 2 (functionality to anticipate part 5)
+  if (length(which(ls() == "epochvalues2csv")) == 0)  epochvalues2csv = FALSE
+  if (length(which(ls() == "mvpa.2014")) == 0) mvpa.2014 = TRUE
+  if (length(which(ls() == "window.summary.size")) == 0) window.summary.size = 10
+  if (length(which(ls() == "dayborder")) == 0)  dayborder = 0
   
   cat("\n   g.shell.GGIR {GGIR} by Vincent van Hees\n")
+  
   if (dopart1 == TRUE) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
     cat("\nPart 1\n")
     g.part1(datadir=datadir,outputdir=outputdir,f0=f0,f1=f1,windowsizes = windowsizes, 
-            desiredtz = desiredtz,chunksize=chunksize,studyname=studyname,
+            desiredtz = desiredtz,chunksize=chunksize,studyname=studyname,minloadcrit=minloadcrit,
             do.enmo = do.enmo,
             do.lfenmo = do.lfenmo,do.en = do.en,
             do.bfen = do.bfen,do.hfen=do.hfen,
@@ -128,21 +161,23 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
             do.anglex=do.anglex,do.angley=do.angley,do.anglez=do.anglez,
             do.enmoa = do.enmoa,printsummary=printsummary,
             do.cal = do.cal,print.filename=print.filename,
-            overwrite=overwrite,backup.cal.coef=backup.cal.coef)
+            overwrite=overwrite,backup.cal.coef=backup.cal.coef,selectdaysfile=selectdaysfile,dayborder=dayborder)
   }
   if (dopart2 == TRUE) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
     cat("\nPart 2\n")
     if (f1 == 0) f1 = length(dir(paste(metadatadir,"/meta/basic",sep="")))
-    g.part2(datadir =datadir ,metadatadir=metadatadir,f0=f0,f1=f1,strategy = strategy, 
+    g.part2(datadir =datadir,metadatadir=metadatadir,f0=f0,f1=f1,strategy = strategy, 
             hrs.del.start = hrs.del.start,hrs.del.end = hrs.del.end,
             maxdur =  maxdur, includedaycrit = includedaycrit,
             L5M5window = L5M5window, M5L5res = M5L5res, winhr = winhr,
             qwindow=qwindow, qlevels = qlevels,
             ilevels = ilevels, mvpathreshold = mvpathreshold,
             boutcriter = boutcriter,ndayswindow=ndayswindow,idloc=idloc,do.imp=do.imp,
-            storefolderstructure=storefolderstructure,overwrite=overwrite)
+            storefolderstructure=storefolderstructure,overwrite=overwrite,epochvalues2csv=epochvalues2csv,
+            mvpadur=mvpadur,selectdaysfile=selectdaysfile,mvpa.2014=mvpa.2014,window.summary.size=window.summary.size,
+            dayborder=dayborder,closedbout=closedbout)
   }
   if (dopart3 == TRUE) {
     cat('\n')
@@ -166,11 +201,31 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
             sleeplogidnum=sleeplogidnum,def.noc.sleep=def.noc.sleep,do.visual = do.visual, #
             storefolderstructure=storefolderstructure,overwrite=overwrite)
   }
-
+#   if (dopart5 == TRUE) {
+#     cat('\n')
+#     cat(paste0(rep('_',options()$width),collapse=''))
+#     cat("\nPart 5\n")
+#     if (f1 == 0) f1 = length(dir(paste(metadatadir,"/meta/ms4.out",sep="")))
+#     g.part5(datadir=datadir,metadatadir=metadatadir,f0=f0,f1=f1,strategy=strategy,maxdur=maxdur,
+#             hrs.del.start=hrs.del.start,
+#             hrs.del.end=hrs.del.end,
+#             loglocation=loglocation,excludefirstlast=excludefirstlast,
+#             windowsizes=windowsizes,boutcriter.in=boutcriter.in,boutcriter.lig=boutcriter.lig,
+#             boutcriter.mvpa=boutcriter.mvpa,storefolderstructure=storefolderstructure,
+#             threshold.lig = threshold.lig,
+#             threshold.mod = threshold.mod,
+#             threshold.vig = threshold.vig,timewindow=timewindow,
+#             boutdur.mvpa = boutdur.mvpa,
+#             boutdur.in = boutdur.in,
+#             boutdur.lig = boutdur.lig,
+#             winhr = winhr,M5L5res = M5L5res,
+#             overwrite=overwrite,desiredtz=desiredtz)
+#   }
+  
   #==========================
   # Report generation:
   # check a few basic assumptions before continuing
-  if (length(which(do.report==4)) > 0 | visualreport==TRUE) {
+  if (length(which(do.report==4 | do.report==5)) > 0 | visualreport==TRUE) {
     if (file.exists(paste(metadatadir,"/meta/ms4.out",sep=""))) {
     } else {
       cat("ERROR: First run g.shell.GGIR with mode = 4 to generate required milestone data\n")
@@ -188,21 +243,33 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     cat(paste0(rep('_',options()$width),collapse=''))
     cat("\nReport part 2\n")
     N.files.ms2.out = length(dir(paste(metadatadir,"/meta/ms2.out",sep="")))
+    if (N.files.ms2.out < f0) f0 = 1
     if (N.files.ms2.out < f1) f1 = N.files.ms2.out
     if (f1 == 0) f1 = N.files.ms2.out
-    g.report.part2(metadatadir=metadatadir,f0=f0,f1=f1,maxdur=maxdur)
+    g.report.part2(metadatadir=metadatadir,f0=f0,f1=f1,maxdur=maxdur,selectdaysfile=selectdaysfile)
   }
   if (length(which(do.report == 4)) > 0) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
     cat("\nReport part 4\n")
     N.files.ms4.out = length(dir(paste(metadatadir,"/meta/ms4.out",sep="")))
+    if (N.files.ms4.out < f0) f0 = 1
     if (N.files.ms4.out < f1) f1 = N.files.ms4.out
     if (f1 == 0) f1 = N.files.ms4.out
     g.report.part4(datadir=datadir,metadatadir=metadatadir,loglocation =loglocation,f0=f0,f1=f1,
                    storefolderstructure=storefolderstructure)
   }
-
+#   if (length(which(do.report == 5)) > 0) {
+#     cat('\n')
+#     cat(paste0(rep('_',options()$width),collapse=''))
+#     cat("\nReport part 5\n")
+#     N.files.ms5.out = length(dir(paste(metadatadir,"/meta/ms5.out",sep="")))
+#     if (N.files.ms5.out < f0) f0 = 1
+#     if (N.files.ms5.out < f1) f1 = N.files.ms5.out
+#     if (f1 == 0) f1 = N.files.ms5.out
+#     g.part5.report(metadatadir=metadatadir,f0=f0,f1=f1,loglocation=loglocation,
+#                    includenightcrit=includenightcrit,includedaycrit=includedaycrit)
+#   }
   if (visualreport == TRUE) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
